<template>
	<div class="system-add-dept-container">
		<el-dialog :title="title" v-model="isShowDialog" width="600px">
			<el-form :model="departmentForm" size="default" label-width="90px">
				<el-row :gutter="35">
					<el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
						<el-form-item label="上级部门">
							<el-cascader
								:options="deptData"
								:props="{ checkStrictly: true, value: 'id', label: 'name' }"
								placeholder="请选择部门"
								clearable
								class="w100"
								v-model="departmentForm.struct"
							>
							</el-cascader>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
						<el-form-item label="部门名称">
							<el-input v-model="departmentForm.name" placeholder="请输入部门名称" clearable></el-input>
						</el-form-item>
					</el-col>
					<el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
						<el-form-item label="部门描述">
							<el-input v-model="departmentForm.info" type="textarea" placeholder="请输入部门描述" maxlength="150"></el-input>
						</el-form-item>
					</el-col>
				</el-row>
			</el-form>
			<template #footer>
				<span class="dialog-footer">
					<el-button @click="onCancel" size="default">取 消</el-button>
					<el-button type="primary" @click="onSubmit" size="default">新 增</el-button>
				</span>
			</template>
		</el-dialog>
	</div>
</template>

<script lang="ts">
import { ElMessage } from 'element-plus';
import { reactive, toRefs, onMounted, defineComponent } from 'vue';
import { departmentApi } from "/@/api/department";

// 定义接口来定义对象的类型
interface TableDataRow {
	struct: Array<string>;
	name:string,
	info:string,
	parentId:string,
	id:number,
}
interface DeptSate {
	title:string;
	isShowDialog: boolean;
	departmentForm: {
		struct: Array<string>;
		name:string,
		info:string,
		parentId:string
	};
	deptData: Array<TableDataRow>;
}

export default defineComponent({
	name: 'systemAddDept',
	setup(prop,context) {
		const state = reactive<DeptSate>({
			title:'',
			isShowDialog: false,
			departmentForm: {
				name:'',
				parentId:'',
				info:'',
				struct:[]
			},
			deptData: [], // 部门数据
		});
		// 打开弹窗
		const openDialog = (type:string, value: any,departmentList: []) => {
			state.isShowDialog = true;
			state.deptData = JSON.parse(JSON.stringify(departmentList))
			if(type === '新增'){
				state.title = '新增部门'
				state.departmentForm = {
					name:'',
					parentId:'',
					info:'',
					struct:[]
				}
			}else{
				state.title = '编辑部门'
			}
		};
		// 关闭弹窗
		const closeDialog = () => {
			state.isShowDialog = false;
		};
		// 取消
		const onCancel = () => {
			closeDialog();
		};
		// 新增
		const onSubmit = async () => {
			if(state.departmentForm.struct && state.departmentForm.struct !== []){
				let departmentId = JSON.parse(JSON.stringify(state.departmentForm.struct))
				state.departmentForm.parentId = departmentId[departmentId.length - 1]
			}
			if(state.title === '新增部门'){
				let res = await departmentApi().addDepartment(state.departmentForm)
				if(res.data.code === '200'){
					ElMessage({
						type:'success',
						message:'菜单新增成功',
						duration:2000
					})
					closeDialog();
					context.emit('getMenuList')
				}else{
					ElMessage({
						type:'warning',
						message:res.data.msg
					})
				}
			}else{
				let res = await departmentApi().modDepartment(state.departmentForm)
				if(res.data.code === '200'){
					ElMessage({
						type:'success',
						message:'菜单修改成功',
						duration:2000
					})
					closeDialog();
					context.emit('getMenuList')
				}else{
					ElMessage({
						type:'warning',
						message:res.data.msg
					})
				}
			}
		};
		// 初始化部门数据
		const initTableData = () => {

		};
		// 页面加载时
		onMounted(() => {
			initTableData();
		});
		return {
			openDialog,
			closeDialog,
			onCancel,
			onSubmit,
			...toRefs(state),
		};
	},
});
</script>
